@@ -17,11 +17,6 @@ foreach $name (split(' ', $Config{sig_name})) {
 	$signo{$name} = $i++;
 }
 
-$timetable = 'cf/timetable';
-if (@ARGV && $ARGV[0] =~ /\//) {
-	$timetable = $ARGV[0];
-	shift @ARGV;
-}
 read_config();
 $now = time;
 $cycle = int(($now-$cycle_epoch)/$cycle_alignment);
@@ -105,7 +100,7 @@ unlink $slot_file;
 
 sub read_config {
 	$action_count = 0;
-	open CF, $timetable or die "Unable to open $timetable";
+	open CF, "cf/timetable" or die "Unable to open cf/timetable";
 	while (<CF>) {
 		chomp;
 		/^\s*($|#)/ && next;
@@ -118,9 +113,7 @@ sub read_config {
 			$action_term[$i] = ($2 ne "") ? $2 : 0;
 			$action_timeout[$i] = $3;
 			$action_cmd[$i] = $4;
-			if ($action_cmd[$i] =~ m/^{.*}$/) { $action_shortname[$i] = "Perl expression"; }
-			elsif ($action_cmd[$i] =~ /^(\S+)/) { $action_shortname[$i] = $1; }
-			else { $action_shortname[$i] = "???"; }
+			$action_shortname[$i] = ($action_cmd[$i] =~ /^(\S+)/) ? $1 : "???";
 		} else {
 			die "Configuration parse error: $_";
 		}
@@ -144,7 +137,15 @@ sub msg {
 sub send_report {
 	my ($address, $subject) = @_;
 	$address ne "" or return;
-	open(MAIL, "|bin/send-mail -s '$subject' $address") or msg("E", "Unable to send mail with report!");
+	my $hdr_address = $address;
+	$hdr_address =~ s/\s+/, /g;
+	open(MAIL, "|/usr/sbin/sendmail $address") or msg("E", "Unable to send mail with report!");
+	my $host = `hostname`; chomp $host;
+	my $whoami = `whoami`; chomp $whoami;
+	print MAIL "From: Sherlock at $host <$whoami>\n";
+	print MAIL "To: $hdr_address\n";
+	print MAIL "Subject: $subject\n";
+	print MAIL "\n";
 	print MAIL "Hello, Sherlock Scheduler speaking out its status report...\n\n";
 	print MAIL "$subject\n\n";
 	if (defined $log_slot_start && open(L, "<$current_logfile")) {
@@ -157,18 +158,11 @@ sub send_report {
 
 sub run_cmd {
 	my ($cmd, $term, $timeout, $shortname) = @_;
-	if ($cmd =~ m/^{.*}$/) {
-		msg("D", "Evaluating $cmd") if $trace;
-		$cmd = eval $cmd;
-		if ($cmd eq "") { return; }
-		elsif ($cmd =~ /^(\S+)/) { $shortname = $1; }
-	}
 	msg("D", "Running '$cmd' term=$term timeout=$timeout") if $trace;
 	my $pid = fork;
 	defined $pid or fatal "fork failed: $!";
 	if (!$pid) {
-		my $exec = ($cmd !~ "[|&;()<>]") ? "exec " : "";
-		exec("/bin/sh", "-c", "$exec$cmd") or exit 127;
+		exec("/bin/sh", "-c", "exec $cmd") or exit 127;
 	}
 	local $SIG{ALRM} = sub {
 		if ($term) {
